==> havp-0.51.tar.gz: havp-0.51/havp/logfile.h <==
/***************************************************************************
                          logfile.h  -  description
                             -------------------
    begin                : Sa Feb 12 2005
    copyright            : (C) 2005 by Christian Hilgers
    email                : christian@hilgers.ag
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LOGFILE_H
#define LOGFILE_H

#include "default.h"

//#include <sys/types.h>
//#include <sys/stat.h>

#include <fcntl.h>
#include <stdarg.h>
#include <unistd.h>

#include <iostream>

using namespace std;


class LogFile {

private:

static int Error_fd;
static int Access_fd;

static void WriteDateAndTime( int fdT );

public:

static bool InitLogFiles ( const char *AccessLogFileT, const char *ErrorLogFileT );

static void AccessMessage( const char *formatT, ... );

static void ErrorMessage( const char *formatT, ... );
   
};

#endif

==> havp_0.90.orig.tar.gz: havp-0.90/havp/logfile.h <==
/***************************************************************************
                          logfile.h  -  description
                             -------------------
    begin                : Sa Feb 12 2005
    copyright            : (C) 2005 by Christian Hilgers
    email                : christian@hilgers.ag
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LOGFILE_H
#define LOGFILE_H

#include <string>

using namespace std;

class LogFile {

private:

static int Error_fd;
static int Access_fd;

static bool UseSyslog;
static int SyslogLevel;
static int SyslogVirusLevel;

static int GetSyslogLevel();
static int GetSyslogVirusLevel();
static int GetSyslogFacility();

public:

static bool InitLogFiles( const char *AccessLogFileT, const char *ErrorLogFileT );
static void AccessMessage( const char *formatT, ... );
static void VirusMessage( const char *formatT, ... );
static void ErrorMessage( const char *formatT, ... );
   
};

#endif
